==> soceda-deployer-model-v0.2-sources.jar: seacloud/petalslink/com/data/_1/ObjectFactory.java <==

package seacloud.petalslink.com.data._1;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the seacloud.petalslink.com.data._1 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: seacloud.petalslink.com.data._1
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AddResourcesDescriptorResponse }
     * 
     */
    public AddResourcesDescriptorResponse createAddResourcesDescriptorResponse() {
        return new AddResourcesDescriptorResponse();
    }

    /**
     * Create an instance of {@link ResourcesDescriptor }
     * 
     */
    public ResourcesDescriptor createResourcesDescriptor() {
        return new ResourcesDescriptor();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link AddResourcesDescriptor }
     * 
     */
    public AddResourcesDescriptor createAddResourcesDescriptor() {
        return new AddResourcesDescriptor();
    }

}

==> soceda-deployer-model-v0.3-sources.jar: seacloud/petalslink/com/data/_1/ObjectFactory.java <==

package seacloud.petalslink.com.data._1;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the seacloud.petalslink.com.data._1 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: seacloud.petalslink.com.data._1
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AddResourcesDescriptorResponse }
     * 
     */
    public AddResourcesDescriptorResponse createAddResourcesDescriptorResponse() {
        return new AddResourcesDescriptorResponse();
    }

    /**
     * Create an instance of {@link ResourcesDescriptor }
     * 
     */
    public ResourcesDescriptor createResourcesDescriptor() {
        return new ResourcesDescriptor();
    }

    /**
     * Create an instance of {@link AddResourcesDescriptorFromURLResponse }
     * 
     */
    public AddResourcesDescriptorFromURLResponse createAddResourcesDescriptorFromURLResponse() {
        return new AddResourcesDescriptorFromURLResponse();
    }

    /**
     * Create an instance of {@link PingResponse }
     * 
     */
    public PingResponse createPingResponse() {
        return new PingResponse();
    }

    /**
     * Create an instance of {@link AddResourcesDescriptor }
     * 
     */
    public AddResourcesDescriptor createAddResourcesDescriptor() {
        return new AddResourcesDescriptor();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link Ping }
     * 
     */
    public Ping createPing() {
        return new Ping();
    }

    /**
     * Create an instance of {@link AddResourcesDescriptorFromURL }
     * 
     */
    public AddResourcesDescriptorFromURL createAddResourcesDescriptorFromURL() {
        return new AddResourcesDescriptorFromURL();
    }

}
